summaryrefslogtreecommitdiffstats
path: root/kmahjongg/GameTimer.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:58:26 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:58:26 +0000
commit838baf3f99ec5ab81b063eb5449a3381d860f377 (patch)
treedd31abcfde08ca92e4623b8f50b3d762a87c997a /kmahjongg/GameTimer.cpp
parent2bf598bafa22fac4126fc8842df6b0119aadc0e9 (diff)
downloadtdegames-838baf3f99ec5ab81b063eb5449a3381d860f377.tar.gz
tdegames-838baf3f99ec5ab81b063eb5449a3381d860f377.zip
TQt4 port kdegames
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1236074 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmahjongg/GameTimer.cpp')
-rw-r--r--kmahjongg/GameTimer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmahjongg/GameTimer.cpp b/kmahjongg/GameTimer.cpp
index f3ce4f52..d4fc4009 100644
--- a/kmahjongg/GameTimer.cpp
+++ b/kmahjongg/GameTimer.cpp
@@ -8,11 +8,11 @@
//
// Constructs a GameTimer widget with a parent and a name.
//
-GameTimer::GameTimer( TQWidget *parent, const char *name )
- : TQLCDNumber( parent, name )
+GameTimer::GameTimer( TQWidget *tqparent, const char *name )
+ : TQLCDNumber( tqparent, name )
{
showingColon = false;
setNumDigits(7);
@@ -8,11 +8,11 @@
//
-// Constructs a GameTimer widget with a parent and a name.
+// Constructs a GameTimer widget with a tqparent and a name.
//